@@ -16,7 +16,7 @@ class TestExtensions < Minitest::Test
 
     CommonMarker.render_html(@markdown, :DEFAULT, %i[table]).tap do |out|
       refute out.include?('| a')
-      %w(<table> <tr> <th> a </th> <td> c </td> <strong>x</strong>).each { |html| assert out.include?(html) }
+      %w[<table> <tr> <th> a </th> <td> c </td> <strong>x</strong>].each { |html| assert out.include?(html) }
       assert out.include?('~~hi~~')
     end
 
@@ -34,7 +34,6 @@ class TestExtensions < Minitest::Test
       refute out.include?('| <strong>x</strong>')
       refute out.include?('~~hi~~')
     end
-
   end
 
   def test_extensions_with_renderers
@@ -42,13 +41,13 @@ class TestExtensions < Minitest::Test
 
     doc.to_html.tap do |out|
       refute out.include?('| a')
-      %w(<table> <tr> <th> a </th> <td> c </td> <strong>x</strong>).each { |html| assert out.include?(html) }
+      %w[<table> <tr> <th> a </th> <td> c </td> <strong>x</strong>].each { |html| assert out.include?(html) }
       assert out.include?('~~hi~~')
     end
 
     HtmlRenderer.new.render(doc).tap do |out|
       refute out.include?('| a')
-      %w(<table> <tr> <th> a </th> <td> c </td> <strong>x</strong>).each { |html| assert out.include?(html) }
+      %w[<table> <tr> <th> a </th> <td> c </td> <strong>x</strong>].each { |html| assert out.include?(html) }
       assert out.include?('~~hi~~')
     end
 
@@ -64,51 +63,51 @@ class TestExtensions < Minitest::Test
 
   def test_comments_are_kept_as_expected
     assert_equal "<!--hello--> <blah> &lt;xmp>\n",
-      CommonMarker.render_html("<!--hello--> <blah> <xmp>\n", :UNSAFE, %i[tagfilter])
+                 CommonMarker.render_html("<!--hello--> <blah> <xmp>\n", :UNSAFE, %i[tagfilter])
   end
 
   def test_table_prefer_style_attributes
-      assert_equal(<<-HTML, CommonMarker.render_html(<<-MD, :TABLE_PREFER_STYLE_ATTRIBUTES, %i[table]))
-<table>
-<thead>
-<tr>
-<th style="text-align: left">aaa</th>
-<th>bbb</th>
-<th style="text-align: center">ccc</th>
-<th>ddd</th>
-<th style="text-align: right">eee</th>
-</tr>
-</thead>
-<tbody>
-<tr>
-<td style="text-align: left">fff</td>
-<td>ggg</td>
-<td style="text-align: center">hhh</td>
-<td>iii</td>
-<td style="text-align: right">jjj</td>
-</tr>
-</tbody>
-</table>
-      HTML
-aaa | bbb | ccc | ddd | eee
-:-- | --- | :-: | --- | --:
-fff | ggg | hhh | iii | jjj
-      MD
+    assert_equal(<<~HTML, CommonMarker.render_html(<<~MD, :TABLE_PREFER_STYLE_ATTRIBUTES, %i[table]))
+      <table>
+      <thead>
+      <tr>
+      <th style="text-align: left">aaa</th>
+      <th>bbb</th>
+      <th style="text-align: center">ccc</th>
+      <th>ddd</th>
+      <th style="text-align: right">eee</th>
+      </tr>
+      </thead>
+      <tbody>
+      <tr>
+      <td style="text-align: left">fff</td>
+      <td>ggg</td>
+      <td style="text-align: center">hhh</td>
+      <td>iii</td>
+      <td style="text-align: right">jjj</td>
+      </tr>
+      </tbody>
+      </table>
+    HTML
+      aaa | bbb | ccc | ddd | eee
+      :-- | --- | :-: | --- | --:
+      fff | ggg | hhh | iii | jjj
+    MD
   end
 
   def test_plaintext
-    assert_equal(<<-HTML, CommonMarker.render_doc(<<-MD, :DEFAULT, %i[table strikethrough]).to_plaintext)
-Hello ~there~.
+    assert_equal(<<~HTML, CommonMarker.render_doc(<<~MD, :DEFAULT, %i[table strikethrough]).to_plaintext)
+      Hello ~there~.
 
-| a |
-| --- |
-| b |
+      | a |
+      | --- |
+      | b |
     HTML
-Hello ~~there~~.
+      Hello ~~there~~.
 
-| a |
-| - |
-| b |
+      | a |
+      | - |
+      | b |
     MD
   end
 end
