@@ -5,15 +5,15 @@ require 'test_helper'
 class TestFootnotes < Minitest::Test
   def setup
     @doc = CommonMarker.render_doc("Hello[^hi].\n\n[^hi]: Hey!\n", :FOOTNOTES)
-    @expected = <<-HTML
-<p>Hello<sup class="footnote-ref"><a href="#fn1" id="fnref1">1</a></sup>.</p>
-<section class="footnotes">
-<ol>
-<li id="fn1">
-<p>Hey! <a href="#fnref1" class="footnote-backref">↩</a></p>
-</li>
-</ol>
-</section>
+    @expected = <<~HTML
+      <p>Hello<sup class="footnote-ref"><a href="#fn1" id="fnref1">1</a></sup>.</p>
+      <section class="footnotes">
+      <ol>
+      <li id="fn1">
+      <p>Hey! <a href="#fnref1" class="footnote-backref">↩</a></p>
+      </li>
+      </ol>
+      </section>
     HTML
   end
 
