@@ -7,13 +7,13 @@ class TestTasklists < Minitest::Test
     text = <<-MD
  - [x] Add task list
  - [ ] Define task list
-MD
+    MD
     @doc = CommonMarker.render_doc(text, :DEFAULT, %i[tasklist])
-    @expected = <<-HTML
-<ul>
-<li><input type="checkbox" checked="" disabled="" /> Add task list</li>
-<li><input type="checkbox" disabled="" /> Define task list</li>
-</ul>
+    @expected = <<~HTML
+      <ul>
+      <li><input type="checkbox" checked="" disabled="" /> Add task list</li>
+      <li><input type="checkbox" disabled="" /> Define task list</li>
+      </ul>
     HTML
   end
 
@@ -28,6 +28,16 @@ MD
   def test_tasklist_state
     list = @doc.first_child
     assert_equal 'checked', list.first_child.tasklist_state
+    assert list.first_child.tasklist_item_checked?
     assert_equal 'unchecked', list.first_child.next.tasklist_state
+    refute list.first_child.next.tasklist_item_checked?
+  end
+
+  def test_set_tasklist_state
+    list = @doc.first_child
+    list.first_child.tasklist_item_checked = false
+    refute list.first_child.tasklist_item_checked?
+    list.first_child.next.tasklist_item_checked = true
+    assert list.first_child.next.tasklist_item_checked?
   end
 end
